@@ -282,8 +282,8 @@ class VideoDownloader:
             if not re.match(r"^[a-z0-9]+$", ext):
                 logger.warning(f"[VideoDownloader] Invalid ext {ext}, forcing mp4")
                 ext = "mp4"
-
-            final_path = video_path or self.video_path or info.get("video_path") or os.path.join(self.download_directory, f"video.{ext}")
+            directory =info.get('directory')
+            final_path = os.path.join(directory, f"video.{ext}")
             if temp_path != final_path and os.path.isfile(temp_path):
                 shutil.move(temp_path, final_path)
 
@@ -304,6 +304,7 @@ class VideoDownloader:
             logger.info(f"[VideoDownloader] Stored in registry at {info['video_path']}")
             return info
 
+
         except Exception as e:
             logger.error(f"[VideoDownloader] Download failed: {e}")
             return None
@@ -339,7 +340,6 @@ def get_video_info_spec(
     video_url=None,
     download=None
     ):
-
     url = url or video_url
     video_info = get_video_info(
         url=url,
@@ -350,17 +350,13 @@ def get_video_info_spec(
         info_directory=info_directory,
         video_path=video_path,
         download=download
-    )
-    if not video_info:   # yt-dlp failed
-        logger.warning(f"[get_video_info_spec] No info for {url}")
-        return None
 
+    )
     if not key:
         return video_info
-
     value = video_info.get(key)
     if not value:
-        value = make_list(get_any_value(video_info, key) or None)[0]
+         value = make_list(get_any_value(video_info,key) or None)[0]
     return value
 def get_video_id(
     url=None,
